package com.sf.file.service;

import java.io.File;
import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.web.multipart.MultipartFile;

import com.sf.file.domain.SysOss;

/**
 * OSS对象存储Service接口
 * 
 * @author ztzh
 * @date 2024-03-14
 */
public interface ISysOssService {
	/**
	 * 查询OSS对象存储
	 * 
	 * @param id OSS对象存储主键
	 * @return OSS对象存储
	 */
	public SysOss selectSysOssById(String id);

	/**
	 * 查询OSS对象存储列表
	 * 
	 * @param sysOss OSS对象存储
	 * @return OSS对象存储集合
	 */
	public List<SysOss> selectSysOssList(SysOss sysOss);

	/**
	 * 新增OSS对象存储
	 * 
	 * @param sysOss OSS对象存储
	 * @return 结果
	 */
	public int insertSysOss(SysOss sysOss);

	/**
	 * 修改OSS对象存储
	 * 
	 * @param sysOss OSS对象存储
	 * @return 结果
	 */
	public int updateSysOss(SysOss sysOss);

	/**
	 * 批量删除OSS对象存储
	 * 
	 * @param ids 需要删除的OSS对象存储主键集合
	 * @return 结果
	 */
	public int deleteSysOssByIds(String[] ids);

	/**
	 * 删除OSS对象存储信息
	 * 
	 * @param id OSS对象存储主键
	 * @return 结果
	 */
	public int deleteSysOssById(String id);

	SysOss upload(MultipartFile file);

	SysOss upload(File file);

	void download(String ossId, HttpServletResponse response) throws Exception;
}
